@@ -11,7 +11,7 @@ import pytest
 def skip_if_no_django():
     """Raises a skip exception when no Django settings are available"""
     if not django_settings_is_configured():
-        pytest.skip('Test skipped since no Django settings is present.')
+        pytest.skip('no Django settings')
 
 
 def django_settings_is_configured():
