@@ -33,7 +33,6 @@ from .fixtures import live_server  # noqa
 from .fixtures import rf  # noqa
 from .fixtures import settings  # noqa
 from .fixtures import transactional_db  # noqa
-from .pytest_compat import getfixturevalue
 
 from .lazy_django import django_settings_is_configured, skip_if_no_django
 
@@ -184,6 +183,10 @@ def pytest_load_initial_conftests(early_config, parser, args):
         'the `urls` attribute of Django `TestCase` objects.  *modstr* is '
         'a string specifying the module of a URL config, e.g. '
         '"my_app.test_urls".')
+    early_config.addinivalue_line(
+        'markers',
+        'ignore_template_errors(): ignore errors from invalid template '
+        'variables (if --fail-on-template-vars is used).')
 
     options = parser.parse_known_args(args)
 
@@ -264,12 +267,13 @@ def pytest_configure():
 def _classmethod_is_defined_at_leaf(cls, method_name):
     super_method = None
 
-    for base_cls in cls.__bases__:
-        if hasattr(base_cls, method_name):
-            super_method = getattr(base_cls, method_name)
+    for base_cls in cls.__mro__[1:]:  # pragma: no branch
+        super_method = base_cls.__dict__.get(method_name)
+        if super_method is not None:
+            break
 
     assert super_method is not None, (
-        '%s could not be found in base class' % method_name)
+        '%s could not be found in base classes' % method_name)
 
     method = getattr(cls, method_name)
 
@@ -293,7 +297,7 @@ def _disable_class_methods(cls):
 
     _disabled_classmethods[cls] = (
         # Get the classmethod object (not the resulting bound method),
-        # otherwise inheritence will be broken when restoring.
+        # otherwise inheritance will be broken when restoring.
         cls.__dict__.get('setUpClass'),
         _classmethod_is_defined_at_leaf(cls, 'setUpClass'),
         cls.__dict__.get('tearDownClass'),
@@ -386,17 +390,17 @@ def _django_db_marker(request):
     if marker:
         transaction = validate_django_db(marker)
         if transaction:
-            getfixturevalue(request, 'transactional_db')
+            request.getfixturevalue('transactional_db')
         else:
-            getfixturevalue(request, 'db')
+            request.getfixturevalue('db')
 
 
 @pytest.fixture(autouse=True, scope='class')
 def _django_setup_unittest(request, django_db_blocker):
     """Setup a django unittest, internal to pytest-django."""
     if django_settings_is_configured() and is_django_unittest(request):
-        getfixturevalue(request, 'django_test_environment')
-        getfixturevalue(request, 'django_db_setup')
+        request.getfixturevalue('django_test_environment')
+        request.getfixturevalue('django_db_setup')
 
         django_db_blocker.unblock()
 
@@ -500,7 +504,7 @@ def _fail_for_invalid_template_variable(request):
     It does not raise an exception, but fails, as the stack trace doesn't
     offer any helpful information to debug.
     This behavior can be switched off using the marker:
-    ``ignore_template_errors``
+    ``pytest.mark.ignore_template_errors``
     """
     class InvalidVarException(object):
         """Custom handler for invalid strings in templates."""
